Python: module excerpts.cmain

excerpts.cmain | index /home/qwer/git/cyclops/fvafrcu/excerpts/excerpts/cmain.py

`## @file
# module functions`

Modules
`` |  |
os | re |  |

Functions
`` |  | convert(lines, comment_character, magic_character) `## Convert Lines to Markdown # # Remove whitespace and magic characters from lines and output valid markdown. # @param lines The lines to be converted. # @param comment_character The comment character of the files language. # @param magic_character The magic character marking lines as markdown # comments. # @return A list of strings containing the lines converted.` extract_md(file_name, comment_character, magic_character) `## Extract Matching Lines # # Extract all lines starting with a combination of comment_character and # magic_character from a file. # @param file_name The file from which the lines are to be extracted. # @param comment_character The comment character of the files language ("#" for # example. # @param magic_character The magic character marking lines as markdown # comments. # @return A list of strings containing the lines extracted.` get_toc(file_name, comment_character, magic_character) `## Get Table of Contents # # Just a wrapper to extract_md() and convert(). # @param file_name The file from which the lines are to be extracted. # @param comment_character The comment character of the files language ("#" for # example). # @param magic_character The magic character marking lines as markdown # comments. # @return A list of strings containing the lines extracted and converted.` modify_path(file_name, postfix='', prefix='', extension=None) `## Modify a Path # # Add a postfix and a prefix to the basename of a path and optionally change # it's extension. # @param file_name The file to be modified. # @param postfix Set the output file postfix. # @param prefix Set the output file prefix. # @param extension Set a new file extension. # @return A string containing the modified path.`

Data
`` |  | print_function = _Feature((2, 6, 0, 'alpha', 2), (3, 0, 0, 'alpha', 0), 65536)